@@ -9,12 +9,11 @@ The client implements all login and logout procedures and is part of every API a
 """
 
 import base64 
+import asyncio
+import logging
 from enum import Enum
 from dataclasses import dataclass
-import base64
-import asyncio
 from datetime import datetime
-import logging
 
 import httpx
 from dracoon.client.models import ProxyConfig
@@ -23,9 +22,8 @@ from dracoon.errors import (MissingCredentialsError, HTTPBadRequestError, HTTPUn
                             HTTPPaymentRequiredError, HTTPForbiddenError, HTTPNotFoundError, HTTPConflictError, HTTPPreconditionsFailedError,
                             HTTPUnknownError)
 
-USER_AGENT = 'dracoon-python-1.8.0'
-DEFAULT_TIMEOUT_CONFIG = httpx.Timeout(10, connect=20, read=20)
-DEFAULT_HTTPX_TRANSPORT = httpx.AsyncHTTPTransport(retries=5)
+USER_AGENT = 'dracoon-python-1.8.4'
+DEFAULT_TIMEOUT_CONFIG = httpx.Timeout(10, connect=30, read=30)
 
 class OAuth2ConnectionType(Enum):
     """ enum as connection type for DRACOONClient """
@@ -56,6 +54,10 @@ class DRACOONClient:
     def __init__(self, base_url: str, client_id: str = 'dracoon_legacy_scripting', client_secret: str = '', redirect_uri: str = None,
                  raise_on_err: bool = False, proxy_config: ProxyConfig = None):
         """ client is initialized with DRACOON instance details (url and OAuth client credentials) """
+        
+        # custom transport for retries on connection errors
+        DEFAULT_HTTPX_TRANSPORT = httpx.AsyncHTTPTransport(retries=5)
+        
         self.base_url = base_url
         self.client_id = client_id
         self.client_secret = client_secret
@@ -103,18 +105,18 @@ class DRACOONClient:
         self.logger.debug("Establishing DRACOON connection...")
         
         # handle missing credentials for password flow
-        if connection_type == OAuth2ConnectionType.password_flow and username == None and password == None:
-            await self.http.aclose()
+        if connection_type == OAuth2ConnectionType.password_flow and username is None and password is None:
+            await self.disconnect()
             self.logger.error("Missing credentials for OAuth2 password flow.")
             raise MissingCredentialsError(message='Username and password are mandatory for OAuth2 password flow.')
 
         # handle missing auth code for authorization code flow 
-        if connection_type == OAuth2ConnectionType.auth_code and auth_code == None:
-            await self.http.aclose()
+        if connection_type == OAuth2ConnectionType.auth_code and auth_code is None:
+            await self.disconnect()
             self.logger.error("Missing auth code for OAuth2 password flow.")
             raise MissingCredentialsError(message='Auth code is mandatory for OAuth2 authorization code flow.')
                 
-        # get connection via OAuth2 password flow
+        # TODO: refactor to own _method
         if connection_type == OAuth2ConnectionType.password_flow:
             data = {'grant_type': 'password',
                 'username': username, 'password': password}
@@ -140,7 +142,7 @@ class DRACOONClient:
             self.connection = DRACOONConnection(now, res.json()["access_token"], res.json()["expires_in"],
                                          res.json()["refresh_token"])
 
-
+        # TODO: refactor to own _method
         if connection_type == OAuth2ConnectionType.auth_code:
             
             if redirect_uri:
@@ -166,17 +168,19 @@ class DRACOONClient:
             self.logger.debug("Access token valid: %s", self.connection.access_token_validity)
 
 
-
+        # TODO: refactor to own _method
         if connection_type == OAuth2ConnectionType.refresh_token:
-
-            if self.connection:
+            
+            # only use connection refresh token if no token is provided
+            if self.connection and refresh_token is None:
                 refresh_token = self.connection.refresh_token
-            if refresh_token == None:
+            # raise if no connection and no token provided
+            if refresh_token is None:
+                await self.disconnect()
                 raise MissingCredentialsError(message='Missing refresh token.')
 
             data = {'grant_type': 'refresh_token', 'refresh_token': refresh_token, 'client_id': self.client_id, 'client_secret': self.client_secret}
 
-
             try:
                 res = await self.http.post(url=token_url, data=data)
                 res.raise_for_status()
@@ -198,6 +202,7 @@ class DRACOONClient:
         return self.connection
 
     async def disconnect(self):
+        """ close async httpx clients """
         await self.http.aclose()
         await self.downloader.aclose()
         await self.uploader.aclose()
@@ -275,16 +280,17 @@ class DRACOONClient:
         return await self.check_access_token()
 
 
-    async def handle_http_error(self, err: httpx.HTTPStatusError, raise_on_err: bool, is_xml: bool = False, close_client: bool = False):
+    async def handle_http_error(self, err: httpx.HTTPStatusError, raise_on_err: bool, is_xml: bool = False, close_client: bool = False, debug_content: bool = True):
+        """ handle http error in httpx client """
         if self.raise_on_err:
             raise_on_err = self.raise_on_err
         
-        self.logger.error("HTTP request failed: %s", err.response.status_code)
+        self.logger.debug("HTTP request failed: %s", err.response.status_code)
         
         # handle AWS S3 XML responses
-        if not is_xml:
+        if debug_content and not is_xml:
             self.logger.debug("%s", err.response.text)
-        elif is_xml:
+        elif debug_content and is_xml:
             self.logger.debug("%s", err.response.content)
 
         if close_client:
@@ -294,12 +300,14 @@ class DRACOONClient:
             self.raise_http_error(err=err)
 
     async def handle_connection_error(self, err: httpx.RequestError):
+        """ handle connection error in httpx client """
         self.logger.critical("Connection error.")
         self.logger.critical(err.request.url)
         await self.disconnect()
         raise err
     
     async def handle_generic_error(self, err: Exception, close_client: bool = False):
+        """ handle generic non-connection / non-http error """
         self.logger.critical("An error ocurred.")
         self.logger.debug("%s", err)
         if close_client:
@@ -307,7 +315,8 @@ class DRACOONClient:
         raise err
 
     def raise_http_error(self, err: httpx.HTTPStatusError):
-
+        """ raise error based on http status code """
+        
         if err.response.status_code == 400:
             raise HTTPBadRequestError(error=err)
         if err.response.status_code == 401:
