@@ -22,20 +22,17 @@ class TestAsyncDRACOONPublic(unittest.IsolatedAsyncioTestCase):
         asyncio.get_running_loop().set_debug(False)
         
         self.dracoon = DRACOONClient(base_url=base_url, client_id=client_id, client_secret=client_secret, raise_on_err=True)
-        await self.dracoon.connect(OAuth2ConnectionType.password_flow, username=username, password=password)
 
         self.public = DRACOONPublic(dracoon_client=self.dracoon)
         self.assertIsInstance(self.public, DRACOONPublic)
-        
-    
+
     async def asyncTearDown(self) -> None:
-        await self.dracoon.logout()
+        await self.dracoon.disconnect()
         
     async def test_get_system_info(self):
         system_info = await self.public.get_system_info()
         self.assertIsInstance(system_info, SystemInfo)
  
-
     async def test_get_ad_info(self):
         auth_ad_info = await self.public.get_auth_ad_info()
         self.assertIsInstance(auth_ad_info, AuthADInfoList)
@@ -51,14 +48,12 @@ class TestAsyncDRACOONServerPublic(unittest.IsolatedAsyncioTestCase):
         asyncio.get_running_loop().set_debug(False)
         
         self.dracoon = DRACOONClient(base_url=base_url_server, client_id=client_id, client_secret=client_secret, raise_on_err=True)
-        await self.dracoon.connect(OAuth2ConnectionType.password_flow, username=username, password=password)
 
         self.public = DRACOONPublic(dracoon_client=self.dracoon)
         self.assertIsInstance(self.public, DRACOONPublic)
         
-    
     async def asyncTearDown(self) -> None:
-        await self.dracoon.logout()
+        await self.dracoon.disconnect()
         
     async def test_get_system_info(self):
         system_info = await self.public.get_system_info()
